<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="iso-8859-1" />

	<xsl:param name="menu">
		<item name="tool" selected="true">Start here</item>
		<item name="faq">FAQ</item>
		<item name="authors">Authors</item>
		<item name="licenses">Licenses</item>
		<item name="separator"/>
		<item name="quickstart">QuickStart</item>
		<item name="documentation">Documentation</item>
		<item name="separator"/>
		<item name="releaseNotes">Release notes</item>
		<item name="todoList">Todo List</item>
		<item name="separator"/>
		<item name="relatedLinks">Links</item>
	</xsl:param>

	<xsl:variable name="first" select="document('')//item[@selected='true']/@name"/>
	<xsl:variable name="lastUpdate" select="//releaseNotes/notes[1]/@date"/>
		
   <xsl:template match="site">
      <html>
         <head>
			<title>
				<xsl:value-of select="tool/short"/>
			</title>
			<style type="text/css">
                #menu {
                    float: left;
                    border: 1px dashed;
                    display: block;
					
					width: 15%;
					margin: 5px;
					padding: 5px;
                }        
                #menu a {
                    display: block;
                }
                #menu a:before {
                    content: url('res/arrow.jpg');
                }
				
				<xsl:for-each select="document('')//item">                    
					<xsl:value-of select="concat('#', @name)" />
					<xsl:if test="position() != last()">,</xsl:if>
				</xsl:for-each> {
					float: left;
                    padding: 0px;
					margin: 15px;
					width: 70%;
                    display: none;
					text-align: justify;
                }        
            
				#subtitle {
					float: right;
					font-style: italic;
				}

                body {
				    font-family: Verdana, Arial, Helvetica, Geneva, SunSans-Regular, sans-serif;
                }
				
				h2 {
                    text-align: center;
					color : #c0aca8;
				    border-bottom : 1px solid black;
				}
				
				h3, h4, h5 {
					color: #336699;
				}

				a {
					color : #336699;
				}
				
				em, dt{
					font-weight: bold;
					font-style: italic;
				}
				
				pre {
					background-color: #eeeeee;
				}
			</style>

			<script type="text/javascript">
                var currentPage = "";
                function setVisible(page){
                    var previousPageElt = document.getElementById(currentPage);
                    if (previousPageElt)
                        previousPageElt.style.display = "";
                    
                    var pageElt = document.getElementById(page);
                    pageElt.style.display = "block";
                    
                    currentPage = page;
                }
            
			</script>
         </head>


         <body onload="setVisible('{$first}')">
			<div id="subtitle">Last updated on <xsl:value-of select="$lastUpdate"/></div>
            <h1>Aspect<span style="color : #336699">DNG</span></h1>

			<div id="menu">
				<xsl:for-each select="document('')//item">
					<xsl:choose>
						<xsl:when test="@name = 'separator'">
							<hr/>
						</xsl:when>
						<xsl:otherwise>
							<a href="javascript:setVisible('{@name}')">
								<xsl:value-of select="." />
							</a>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</div>
            
			<xsl:variable name="root" select="/"/>
			<xsl:for-each select="document('')//item">
				<div id="{@name}">
					<h2><xsl:value-of select="." /></h2>
					<xsl:apply-templates select="$root//*[name() = current()/@name]"/>
				</div>
			</xsl:for-each>

         </body>
      </html>
   </xsl:template>
   	
	<xsl:template match="*">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="node()"/>
		</xsl:copy>
		<!-- force a space after all tags (the pretty printer swallows some of them)-->
		<xsl:text> </xsl:text>
	</xsl:template>
	
	<!-- specific displays -->
	<xsl:template match="tool">
		<xsl:apply-templates select="long/*"/>
		
		<xsl:variable name="lastVersion" select="//releaseNotes/notes[1]/@version"/>
		<p>The last version of AspectDNG (<xsl:value-of select="$lastVersion"/>) can be downloaded in two forms:
		<ul>
			<li> <a href="../releases/aspectdng-{$lastVersion}-bin.zip">Binary distribution</a> </li>
			<li> <a href="../releases/aspectdng-{$lastVersion}-src.zip">Source distribution</a> </li>
		</ul>
		</p>
		
	</xsl:template>
   
	<xsl:template match="authors">
		<ul>
			<xsl:for-each select="author">
				<li><a href="mailto:{@email}"><xsl:value-of select="@name"/></a> <xsl:value-of select="concat(' ', .)"/></li>
			</xsl:for-each>
		</ul>
	</xsl:template>
	
	<xsl:template match="todoList">
		<ul><xsl:apply-templates/></ul>
	</xsl:template>
	
	<xsl:template match="releaseNotes">
		<xsl:for-each select="notes">
			<h3>
				AspectDNG <xsl:value-of select="@version"/> 
				<xsl:if test="@date">
					(<xsl:value-of select="@date"/>)
				</xsl:if>
			</h3>
			<ul><xsl:apply-templates/></ul>
		</xsl:for-each>
	</xsl:template>
		
	<xsl:template match="faq">
		<xsl:for-each select="category">
			<h3><xsl:value-of select="@name"/></h3>
			<xsl:for-each select="qa">
				<h4><xsl:value-of select="@question"/></h4>
				<xsl:apply-templates/>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="licenses">
		<xsl:for-each select="license">
			<h3><xsl:value-of select="@tool"/></h3>
			<xsl:apply-templates/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="relatedLinks">
		<ul>
			<xsl:for-each select="link">
				<li><a href="{@url}"><xsl:value-of select="@title"/></a> : <xsl:value-of select="."/></li>
			</xsl:for-each>
		</ul>
	</xsl:template>
	
	<xsl:template match="documentation">
		<h3>Table of contents</h3>
		<ul>
			<xsl:for-each select="h3">
				<li>
					<a href="#{generate-id(.)}"> <xsl:apply-templates/> </a>
					<ul>
					<xsl:choose>
						<xsl:when test="following-sibling::h3">
							<xsl:for-each select="following-sibling::h4[. = current()/following-sibling::h3[1]/preceding-sibling::h4]">
								<li> <a href="#{generate-id(.)}"> <xsl:apply-templates/> </a> </li>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="following-sibling::h4">
								<li> <a href="#{generate-id(.)}"> <xsl:apply-templates/> </a> </li>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
					</ul>
				</li>
			</xsl:for-each>
		</ul>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="documentation/h3 | documentation/h4">
		<xsl:copy>
			<a name="{generate-id(.)}"> <xsl:apply-templates/> </a>
		</xsl:copy>
	</xsl:template>
	
</xsl:stylesheet>

